package org.expeditee.agents;

import java.awt.Color;
import java.awt.Point;

import org.expeditee.gui.Frame;
import org.expeditee.gui.FrameGraphics;
import org.expeditee.gui.FrameIO;
import org.expeditee.items.Text;

public class SwitchyardTree extends DefaultAgent {

	private Long startTime = 0L;

	private int frameCount = 0;

	private int itemCount = 0;

	@Override
	protected void finalise(Frame frame) {
		Long total = System.currentTimeMillis() - startTime;
		FrameGraphics.DisplayMessage("Time: " + total + "ms, frames: "
				+ frameCount + ", items: " + itemCount);
	}

	@Override
	protected Frame process(Frame frame) {
		frameCount = 0;
		itemCount = 0;
		FrameGraphics.DisplayMessage("Running switchyard tree...");
		startTime = System.currentTimeMillis();

		for (Text textItem : frame.getBodyTextItems(false)) {
			// Delete all non-annotations with more that one letter
			if (textItem.getTextNoList().length() > 1)
				frame.removeItem(textItem);
			else {
				// goto child frame of any linked 1 letter items
				String link = textItem.getAbsoluteLink();
				if (link != null) {
					Frame childFrame = FrameIO.LoadFrame(link);
					if (childFrame != null) {
						Point lastItemEnd = textItem.getEndParagraphPosition();
						for (Text childItem : childFrame.getBodyTextItems(false)) {
							// look for red items
							if (childItem.getColor().equals(Color.RED)) {
								// make a copy and add to parent frame
								Text itemCopy = childItem.copy();
								// add to the right of parent item
								lastItemEnd.translate(20, 0);
								itemCopy.setPosition(lastItemEnd);
								lastItemEnd = itemCopy
										.getEndParagraphPosition();
								frame.addItem(itemCopy);
							}
						}
					}
				}
			}
		}

		return null;
	}
}
